@@ -24,6 +24,9 @@
 
 #define kshutdownrc Config::getInstance()->getInstance()
 
+#define KS_CONFIG_AMOR_MESSAGE "dcop amor AmorIface showMessage \"%appname: %text\""
+#define KS_CONFIG_KDIALOG_MESSAGE "kdialog --title \"%title\" --passivepopup \"%text\" 10"
+
 /**
  * @short A configuration reader/writer.
  * Use the @c kshutdownrc macro to access these members.
@@ -48,6 +51,12 @@ public:
 	int generalDelayType;
 	QDateTime generalDateTime;
 
+	// progress bar
+	bool progressBarEnabled;
+	ItemBool *i_progressBarEnabled;
+	int progressBarPosition;
+	ItemInt *i_progressBarPosition;
+
 	// statistics
 	bool statsLongFormat;
 	ItemBool *i_statsLongFormat;
