@@ -29,9 +29,10 @@ public:
 	/**
 	 * Displays a confirmation message box.
 	 * @param action An action to confirm
+	 * @param delay A selected delay
 	 * @return @c true if action has been confirmed; otherwise @c false
 	 */
-	static bool confirm(const Action::Type action);
+	static bool confirm(const Action::Type action, const QString &delay);
 };
 
 #endif // __CONFIRMATION_H__
