@@ -82,7 +82,7 @@ QString Extras::getActionDescription() const
 			: KStringHandler::csqueeze(_description, 100);
 }
 
-void Extras::setAction(const QString &fileToExecute, const QString &description)
+void Extras::setAction(const QString &fileToExecute, const QString &description, QIconSet *icon)
 {
 	_description = description;
 	_fileToExecute = fileToExecute;
@@ -94,8 +94,10 @@ void Extras::setAction(const QString &fileToExecute, const QString &description)
 	else
 	{
 		_button->setText(getActionDescription());
-// TODO: 2.0: selected item icon
-		_button->setIconSet(ks_actions->getIcon(Action::Extras));
+		if (!icon)
+			_button->setIconSet(ks_actions->getIcon(Action::Extras));
+		else
+			_button->setIconSet(*icon);
 	}
 }
 
@@ -219,12 +221,24 @@ bool Extras::execFile() const
 		return false;
 	}
 
-	pid_t pid = KRun::runURL(
-		KURL::fromPathOrURL(_fileToExecute),
-		KMimeType::findByPath(_fileToExecute)->name()
-	);
 
-	return pid;
+	// HACK: It seems that KRun::runURL sometimes does not work for hibernate :/ ?
+	QFileInfo fi(_fileToExecute);
+	if (fi.fileName() == "hibernate.desktop") {
+		kdDebug() << "Extras::execFile(): Using hacked run..." << endl;
+
+		pid_t pid = KRun::runCommand("kfmclient exec \"" + _fileToExecute + "\"");
+		
+		return pid;	
+	}
+	else {	
+		pid_t pid = KRun::runURL(
+			KURL::fromPathOrURL(_fileToExecute),
+			KMimeType::findByPath(_fileToExecute)->name()
+		);
+		
+		return pid;
+	}
 }
 
 QMap<int, QString> *Extras::getIdToFileMap()
@@ -273,7 +287,7 @@ void Extras::slotActivated(int id)
 	}
 	else
 	{
-		setAction(i.data(), _menu->text(id));
+		setAction(i.data(), _menu->text(id), _menu->iconSet(id));
 	}
 }
 
