@@ -17,6 +17,8 @@
 	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
+#include <sys/types.h>
+
 #include "configuration.h"
 #include "miscutils.h"
 #include "mmainwindow.h"
@@ -26,10 +28,16 @@
 #include <qtooltip.h>
 #include <qwhatsthis.h>
 
+#include <kaction.h>
+#include <kdebug.h>
+#include <kiconloader.h>
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <knotifyclient.h>
+#include <kpassivepopup.h>
+#include <kpushbutton.h>
 #include <krun.h>
+#include <kwindowinfo.h>
 
 // public
 
@@ -92,59 +100,53 @@ bool MiscUtils::isRestricted(const QString &key)
 
 void MiscUtils::notifyUser(const int secs)
 {
+	if ((secs < 60) && (secs % 3 == 0)) {
+		KWindowInfo::showMessage(ks_main, i18n("Warning"), SmallIcon("messagebox_warning"), 1000);
+	}
+
 	switch (secs)
 	{
 		case 3600: // 1 hour
 			customMessage(i18n("1 hour warning"));
 			break;
 		case 300: // 5 minutes
-			playSound("kshutdown-5m", i18n("5 minutes warning"));
+			notifyUser("kshutdown-5m", i18n("5 minutes warning"));
 			customMessage(i18n("5 minutes warning"));
 			break;
 		case 60: // 1 minute
-			playSound("kshutdown-1m", i18n("1 minute warning"));
+			notifyUser("kshutdown-1m", i18n("1 minute warning"));
 			customMessage(i18n("1 minute warning"));
 			break;
 		case 10: // 10 seconds
 			customMessage(i18n("10 seconds warning"));
 			break;
-		case 3: // 3 seconds
-			playSound("kshutdown-three", i18n("3 seconds before action"));
-			break;
-		case 2: // 2 seconds
-			playSound("kshutdown-two", i18n("2 seconds before action"));
-			break;
-		case 1: // 1 second
-			playSound("kshutdown-one", i18n("1 second before action"));
-			break;
 	}
 }
 
-void MiscUtils::pack(QWidget *w)
-{
-	if (!w)
-		return;
-
-	QLayout *l = w->layout();
-	if (l)
-		w->setFixedSize(l->minimumSize());
+void MiscUtils::passiveMessage(const QString &text, QWidget *parent) {
+	KPassivePopup *popup = KPassivePopup::message(
+		"KShutDown",
+		text,
+		SmallIcon("kshutdown"),
+		parent
+	);
+	if (parent == 0)
+		popup->move(0, 0);
 }
 
-// TODO: 0.9: rename this method
-void MiscUtils::playSound(const QString &name, const QString &text)
-{
-	WId id;
-	if (MSystemTray::isInstance())
-		id = ks_tray->winId();
-	else
-		id = ks_main->winId();
-	KNotifyClient::event(id, name, text);
+void MiscUtils::plug(const KAction *action, KPushButton *pushButton) {
+	pushButton->disconnect(); // disconnect all
+	pushButton->connect(pushButton, SIGNAL(clicked()), action, SLOT(activate()));
+	pushButton->setIconSet(action->iconSet());
+	QString text = action->text();
+	if (text.contains("%1"))
+		text = text.arg(action->shortcutText());
+	pushButton->setText(text);
 }
 
 bool MiscUtils::runCommand(const QString &command)
 {
-	int pid;
-	pid = KRun::run(command, KURL::List());
+	pid_t pid = KRun::run(command, KURL::List());
 
 	if (pid)
 		return true; // ok
@@ -207,6 +209,12 @@ bool MiscUtils::runShellCommand(const QString &command, const KProcess::RunMode
 	return retVal;
 }
 
+void MiscUtils::setAutostart(const bool yes) {
+	KConfig *config = kapp->config();
+	config->setGroup("KShutDown");
+	config->writeEntry("Autostart", yes);
+}
+
 void MiscUtils::setHint(QWidget *widget, const QString &value)
 {
 	QToolTip::add(widget, value);
@@ -215,10 +223,22 @@ void MiscUtils::setHint(QWidget *widget, const QString &value)
 
 void MiscUtils::showRunErrorMessage(const QString &command)
 {
-	playSound("kshutdown-runerror", i18n("Could not run \"%1\"!").arg(command));
+	notifyUser("kshutdown-runerror", i18n("Could not run \"%1\"!").arg(command));
 }
 
 void MiscUtils::showTestMessage(const QString &message)
 {
 	KMessageBox::information(0, message, i18n("Test"));
 }
+
+// private
+
+void MiscUtils::notifyUser(const QString &name, const QString &text)
+{
+	WId id;
+	if (MSystemTray::isInstance())
+		id = ks_tray->winId();
+	else
+		id = ks_main->winId();
+	KNotifyClient::event(id, name, text);
+}
