@@ -53,6 +53,8 @@
 #include <kpopupmenu.h>
 #include <kpushbutton.h>
 #include <kwin.h>
+#include <kdesktopfile.h>
+#include <kmimetype.h>
 
 MMainWindow *MMainWindow::_instance = 0;
 
@@ -91,7 +93,20 @@ MMainWindow::MMainWindow()
 	QString extrasDescription = config->readEntry("Description", QString::null);
 	if (!extrasCommand.isEmpty() || QFile::exists(extrasCommand)) {
 		setAction(Action::Extras);
-		ks_extras->setAction(extrasCommand, extrasDescription);
+
+		QIconSet extrasIcon;
+		QString mimeType;
+		mimeType = KMimeType::findByPath(extrasCommand)->name();
+		if (mimeType != "application/x-desktop")
+			extrasIcon = QIconSet(KMimeType::pixmapForURL(KURL::fromPathOrURL(extrasCommand)));
+		else {
+			// application/x-desktop
+			KDesktopFile *desktopFile = new KDesktopFile(extrasCommand, true);
+			if (desktopFile->getConfigState() != KConfigBase::NoAccess)
+				extrasIcon = QIconSet(SmallIcon(desktopFile->readIcon()));
+			delete desktopFile;
+		}
+		ks_extras->setAction(extrasCommand, extrasDescription, &extrasIcon);
 	}
 	else {
 		setAction((Action::Type)kshutdownrc->generalAction);
