@@ -35,16 +35,29 @@ class MStatsTab: public KDialogBase
 public:
 	/**
 	 * Constructor.
-	 * @param parent A parent widget
 	 */
-	MStatsTab(QWidget *parent);
+	MStatsTab();
 
 	/**
 	 * Destructor.
 	 */
 	virtual ~MStatsTab();
+
+	inline static MStatsTab *getInstance() {
+		if (!_instance)
+			_instance = new MStatsTab();
+
+		_instance->slotRefresh();
+		_instance->show();
+		_instance->raise();
+
+		return _instance;
+	}
+protected:
+	void keyPressEvent(QKeyEvent *e);
 private:
 	KPushButton *b_refresh;
+	static MStatsTab *_instance;
 	QCheckBox
 		*c_longFormat,
 		*c_toggleFromField;
@@ -52,14 +65,10 @@ private:
 	QString _buf;
 	QTextEdit *te_output;
 	void killProcess() const;
-public slots:
-	/**
-	 * Updates the statistics view.
-	 */
-	void update();
 private slots:
 	void slotProcessExit();
 	void slotReadStdout();
+	void slotRefresh();
 };
 
 #endif // __MSTATSTAB_H__
