@@ -18,11 +18,13 @@
 */
 
 #include "configuration.h"
+#include "miscutils.h"
 #include "mmainwindow.h"
 #include "msystemtray.h"
 
 #include <qtimer.h>
 
+#include <kaction.h>
 #include <kdebug.h>
 #include <kiconloader.h>
 #include <klocale.h>
@@ -84,53 +86,40 @@ void MSystemTray::setMode(const Mode mode)
 			ks_tray; // init instance
 			if (ks_actions->active())
 				_instance->setActive(true);
-// FIXME: 0.9: XSMP error (?) - bad state
-			kapp->enableSessionManagement();
+			_instance->show();
+			MiscUtils::setAutostart(true);
 			break;
 		case IfActive:
 			if (ks_actions->active())
 			{
 				ks_tray; // init instance
 				_instance->setActive(true);
-				kapp->enableSessionManagement();
+				_instance->show();
+				MiscUtils::setAutostart(true);
 			}
 			else
 			{
 				delete _instance;
 				_instance = 0;
-				kapp->disableSessionManagement();
+				MiscUtils::setAutostart(false);
 			}
 			break;
 		case Never:
 			delete _instance;
 			_instance = 0;
-			kapp->disableSessionManagement();
+			MiscUtils::setAutostart(false);
 			break;
 	}
 }
 
 // protected
 
-void MSystemTray::contextMenuAboutToShow(KPopupMenu *menu)
-{
-	if (ks_actions->active())
-	{
-		menu->changeItem(_cancelItem, i18n("&Cancel") + ": " + ks_actions->getCurrentName());
-		menu->setItemEnabled(_cancelItem, true);
-	}
-	else
-	{
-		menu->changeItem(_cancelItem, i18n("&Cancel"));
-		menu->setItemEnabled(_cancelItem, false);
-	}
-}
-
 void MSystemTray::mousePressEvent(QMouseEvent *e)
 {
 	// middle mouse button - display actions menu
-// TODO: 0.9: configure middle button action
+// TODO: 2.0: configure middle button action
 	if (e->button() == MidButton)
-		_actionsMenu->popup(e->globalPos());
+		contextMenu()->popup(e->globalPos());
 	else
 		KSystemTray::mousePressEvent(e);
 }
@@ -145,9 +134,9 @@ MSystemTray::MSystemTray()
 	_flashCount(0),
 	_saveIcon(0)
 {
-	setPixmap(kapp->miniIcon());
+	setPixmap(SmallIcon("exit", KIcon::SizeSmallMedium)); // 22x22
 
-// TODO: 0.9: mouse wheel: decrease/increase end time by 5min. (?)
+// TODO: 2.0: mouse wheel: decrease/increase end time by 5min. (?)
 
 	// init fade timer
 	_fadeTimer = new QTimer(this);
@@ -158,61 +147,24 @@ MSystemTray::MSystemTray()
 	connect(_flashTimer, SIGNAL(timeout()), SLOT(slotFlashTimeout()));
 
 	// init icons
-	KPixmap pm(kapp->miniIcon());
-	_flashIcon = new KPixmap(KPixmapEffect::fade(pm, 0.7f, green));
+	KPixmap pm(SmallIcon("exit", KIcon::SizeSmallMedium));
+	_flashIcon = new KPixmap(KPixmapEffect::fade(pm, 0.7f, white));
 
 	show();
 
 	// add some items to the context menu
-	KPopupMenu *cm = contextMenu();
-	cm->setCaption(i18n("KShutDown Menu"));
-	_actionsMenu = new KPopupMenu(cm, "KPopupMenu::_actionsMenu");
-	_actionsMenu->setCaption(i18n("KShutDown Actions (no delay!)"));
-	_actionsMenu->insertTitle(kapp->miniIcon(), i18n("Actions (no delay!)"));
-	connect(_actionsMenu, SIGNAL(aboutToShow()), SLOT(slotActionsMenuAboutToShow()));
-
-	// shut down
-	_shutDownItem = _actionsMenu->insertItem(
-		ks_actions->getIcon(Action::ShutDown), i18n("&Turn Off Computer"),
-		this, SLOT(slotShutDown())
-	);
-	// reboot
-	_rebootItem = _actionsMenu->insertItem(
-		ks_actions->getIcon(Action::Reboot), i18n("&Restart Computer"),
-		this, SLOT(slotReboot())
-	);
-	// lock screen
-	_lockScreenItem = _actionsMenu->insertItem(
-		ks_actions->getIcon(Action::LockScreen), i18n("&Lock Session"),
-		this, SLOT(slotLockScreen())
-	);
-	// logout
-	_logoutItem = _actionsMenu->insertItem(
-		ks_actions->getIcon(Action::Logout), i18n("&End Current Session"),
-		this, SLOT(slotLogout())
-	);
-	_actionsMenu->insertTearOffHandle();
+	KPopupMenu *pm_systemTrayMenu = contextMenu();
+	pm_systemTrayMenu->setCaption("KShutDown");
 	// id 0 = title
-	cm->insertItem(i18n("&Immediate Action"), _actionsMenu, -1, 1);
-	// cancel
-	_cancelItem = cm->insertItem(
-		SmallIcon("stop"), i18n("&Stop"),
-		ks_main, SLOT(slotCancel()), 0, -1, 2
-	);
-	// -
-	cm->insertSeparator(3);
-	// configure
-	cm->insertItem(
-		SmallIcon("configure"), i18n("Configure &KShutDown..."),
-		ks_main, SLOT(slotConfigure()), 0, -1, 4
-	);
-	// help
-	cm->insertItem(
-		SmallIcon("help"), i18n("&Help"),
-		ks_main->helpMenu(), -1, 5
-	);
-	// -
-	cm->insertTearOffHandle();
+	ks_main->shutDownAction()->plug(pm_systemTrayMenu, 1);
+	ks_main->rebootAction()->plug(pm_systemTrayMenu, 2);
+	ks_main->lockScreenAction()->plug(pm_systemTrayMenu, 3);
+	ks_main->logoutAction()->plug(pm_systemTrayMenu, 4);
+	pm_systemTrayMenu->insertSeparator(5);
+	ks_main->cancelAction()->plug(pm_systemTrayMenu, 6);
+	pm_systemTrayMenu->insertSeparator(7);
+	ks_main->configureKShutDownAction()->plug(pm_systemTrayMenu, 8);
+	pm_systemTrayMenu->insertTearOffHandle();
 
 	// quit signal
 	connect(
@@ -222,14 +174,6 @@ MSystemTray::MSystemTray()
 
 // private slots
 
-void MSystemTray::slotActionsMenuAboutToShow()
-{
-	_actionsMenu->setItemEnabled(_shutDownItem, ks_actions->isEnabled(Action::ShutDown));
-	_actionsMenu->setItemEnabled(_rebootItem, ks_actions->isEnabled(Action::Reboot));
-	_actionsMenu->setItemEnabled(_lockScreenItem, ks_actions->isEnabled(Action::LockScreen));
-	_actionsMenu->setItemEnabled(_logoutItem, ks_actions->isEnabled(Action::Logout));
-}
-
 void MSystemTray::slotFade()
 {
 	if (_incFade)
@@ -250,7 +194,7 @@ void MSystemTray::slotFade()
 			_fadeValue = 0.0f;
 		}
 	}
-	KPixmap p(kapp->miniIcon());
+	KPixmap p(SmallIcon("exit", KIcon::SizeSmallMedium));
 	setPixmap(KPixmapEffect::fade(p, _fadeValue, KS_TRAY_FADE_COLOR));
 }
 
@@ -266,23 +210,3 @@ void MSystemTray::slotFlashTimeout()
 	if (_flashCount == 6)
 		_flashTimer->stop();
 }
-
-void MSystemTray::slotLockScreen()
-{
-	ks_actions->execConfirm(Action::LockScreen);
-}
-
-void MSystemTray::slotLogout()
-{
-	ks_actions->execConfirm(Action::Logout);
-}
-
-void MSystemTray::slotReboot()
-{
-	ks_actions->execConfirm(Action::Reboot);
-}
-
-void MSystemTray::slotShutDown()
-{
-	ks_actions->execConfirm(Action::ShutDown);
-}
