@@ -85,11 +85,6 @@ public:
 	 */
 	static void setMode(const Mode mode);
 protected:
-	/**
-	 * Disables/enables menu items before @p menu becomes visible.
-	 */
-	virtual void contextMenuAboutToShow(KPopupMenu *menu);
-
 	/**
 	 * Overriden to handle middle button click; displays the actions menu.
 	 * @param e A mouse event
@@ -108,24 +103,11 @@ private:
 	QTimer
 		*_fadeTimer,
 		*_flashTimer;
-
-	int
-		_cancelItem,
-		_lockScreenItem,
-		_logoutItem,
-		_rebootItem,
-		_shutDownItem;
-	KPopupMenu *_actionsMenu;
 	static MSystemTray *_instance;
 	MSystemTray();
 private slots:
-	void slotActionsMenuAboutToShow();
 	void slotFade();
 	void slotFlashTimeout();
-	void slotLockScreen();
-	void slotLogout();
-	void slotReboot();
-	void slotShutDown();
 };
 
 #endif // __MSYSTEMTRAY_H__
